==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/customerrentaldefault_001/CustomerRentalDefault.java <==

package net.datastream.schemas.mp_entities.customerrentaldefault_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RENTALTYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NETAMOUNTCURRENCY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTSCURRENCY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TAXAMOUNTCURRENCY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}GROSSAMOUNTCURRENCY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INVOICEDAMOUNTCURRENCY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SECONDARYPHONE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LICENSENO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COSTCODE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "organizationid",
    "status",
    "rentaltype",
    "createddate",
    "createdby",
    "netamountcurrency",
    "adjustmentscurrency",
    "taxamountcurrency",
    "grossamountcurrency",
    "invoicedamountcurrency",
    "issueto",
    "customerid",
    "secondaryphone",
    "licenseno",
    "costcode"
})
@XmlRootElement(name = "CustomerRentalDefault")
public class CustomerRentalDefault {

    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "RENTALTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rentaltype;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "NETAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type netamountcurrency;
    @XmlElement(name = "ADJUSTMENTSCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type adjustmentscurrency;
    @XmlElement(name = "TAXAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type taxamountcurrency;
    @XmlElement(name = "GROSSAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type grossamountcurrency;
    @XmlElement(name = "INVOICEDAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type invoicedamountcurrency;
    @XmlElement(name = "ISSUETO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type issueto;
    @XmlElement(name = "CUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "SECONDARYPHONE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String secondaryphone;
    @XmlElement(name = "LICENSENO", namespace = "http://schemas.datastream.net/MP_fields")
    protected String licenseno;
    @XmlElement(name = "COSTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costcode;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the rentaltype property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRENTALTYPE() {
        return rentaltype;
    }

    /**
     * Sets the value of the rentaltype property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRENTALTYPE(STATUS_Type value) {
        this.rentaltype = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the netamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getNETAMOUNTCURRENCY() {
        return netamountcurrency;
    }

    /**
     * Sets the value of the netamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setNETAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.netamountcurrency = value;
    }

    /**
     * Gets the value of the adjustmentscurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getADJUSTMENTSCURRENCY() {
        return adjustmentscurrency;
    }

    /**
     * Sets the value of the adjustmentscurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setADJUSTMENTSCURRENCY(CURRENCYID_Type value) {
        this.adjustmentscurrency = value;
    }

    /**
     * Gets the value of the taxamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getTAXAMOUNTCURRENCY() {
        return taxamountcurrency;
    }

    /**
     * Sets the value of the taxamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setTAXAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.taxamountcurrency = value;
    }

    /**
     * Gets the value of the grossamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getGROSSAMOUNTCURRENCY() {
        return grossamountcurrency;
    }

    /**
     * Sets the value of the grossamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setGROSSAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.grossamountcurrency = value;
    }

    /**
     * Gets the value of the invoicedamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getINVOICEDAMOUNTCURRENCY() {
        return invoicedamountcurrency;
    }

    /**
     * Sets the value of the invoicedamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setINVOICEDAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.invoicedamountcurrency = value;
    }

    /**
     * Gets the value of the issueto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Sets the value of the issueto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

    /**
     * Gets the value of the customerid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Sets the value of the customerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Gets the value of the secondaryphone property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSECONDARYPHONE() {
        return secondaryphone;
    }

    /**
     * Sets the value of the secondaryphone property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSECONDARYPHONE(String value) {
        this.secondaryphone = value;
    }

    /**
     * Gets the value of the licenseno property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLICENSENO() {
        return licenseno;
    }

    /**
     * Sets the value of the licenseno property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLICENSENO(String value) {
        this.licenseno = value;
    }

    /**
     * Gets the value of the costcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTCODE() {
        return costcode;
    }

    /**
     * Sets the value of the costcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTCODE(String value) {
        this.costcode = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/customerrentaldefault_001/CustomerRentalDefault.java <==

package net.datastream.schemas.mp_entities.customerrentaldefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RENTALTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NETAMOUNTCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTSCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TAXAMOUNTCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROSSAMOUNTCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEDAMOUNTCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SECONDARYPHONE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LICENSENO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "organizationid",
    "status",
    "rentaltype",
    "createddate",
    "createdby",
    "netamountcurrency",
    "adjustmentscurrency",
    "taxamountcurrency",
    "grossamountcurrency",
    "invoicedamountcurrency",
    "issueto",
    "customerid",
    "secondaryphone",
    "licenseno",
    "costcode"
})
@XmlRootElement(name = "CustomerRentalDefault")
public class CustomerRentalDefault {

    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "RENTALTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rentaltype;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "NETAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type netamountcurrency;
    @XmlElement(name = "ADJUSTMENTSCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type adjustmentscurrency;
    @XmlElement(name = "TAXAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type taxamountcurrency;
    @XmlElement(name = "GROSSAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type grossamountcurrency;
    @XmlElement(name = "INVOICEDAMOUNTCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type invoicedamountcurrency;
    @XmlElement(name = "ISSUETO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type issueto;
    @XmlElement(name = "CUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "SECONDARYPHONE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String secondaryphone;
    @XmlElement(name = "LICENSENO", namespace = "http://schemas.datastream.net/MP_fields")
    protected String licenseno;
    @XmlElement(name = "COSTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costcode;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the rentaltype property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRENTALTYPE() {
        return rentaltype;
    }

    /**
     * Sets the value of the rentaltype property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRENTALTYPE(STATUS_Type value) {
        this.rentaltype = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the netamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getNETAMOUNTCURRENCY() {
        return netamountcurrency;
    }

    /**
     * Sets the value of the netamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setNETAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.netamountcurrency = value;
    }

    /**
     * Gets the value of the adjustmentscurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getADJUSTMENTSCURRENCY() {
        return adjustmentscurrency;
    }

    /**
     * Sets the value of the adjustmentscurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setADJUSTMENTSCURRENCY(CURRENCYID_Type value) {
        this.adjustmentscurrency = value;
    }

    /**
     * Gets the value of the taxamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getTAXAMOUNTCURRENCY() {
        return taxamountcurrency;
    }

    /**
     * Sets the value of the taxamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setTAXAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.taxamountcurrency = value;
    }

    /**
     * Gets the value of the grossamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getGROSSAMOUNTCURRENCY() {
        return grossamountcurrency;
    }

    /**
     * Sets the value of the grossamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setGROSSAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.grossamountcurrency = value;
    }

    /**
     * Gets the value of the invoicedamountcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getINVOICEDAMOUNTCURRENCY() {
        return invoicedamountcurrency;
    }

    /**
     * Sets the value of the invoicedamountcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setINVOICEDAMOUNTCURRENCY(CURRENCYID_Type value) {
        this.invoicedamountcurrency = value;
    }

    /**
     * Gets the value of the issueto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Sets the value of the issueto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

    /**
     * Gets the value of the customerid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Sets the value of the customerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Gets the value of the secondaryphone property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSECONDARYPHONE() {
        return secondaryphone;
    }

    /**
     * Sets the value of the secondaryphone property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSECONDARYPHONE(String value) {
        this.secondaryphone = value;
    }

    /**
     * Gets the value of the licenseno property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLICENSENO() {
        return licenseno;
    }

    /**
     * Sets the value of the licenseno property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLICENSENO(String value) {
        this.licenseno = value;
    }

    /**
     * Gets the value of the costcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTCODE() {
        return costcode;
    }

    /**
     * Sets the value of the costcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTCODE(String value) {
        this.costcode = value;
    }

}
